@@ -1,22 +1,9 @@
-/**
-  * This file is part of the KDE project
-  * Copyright (C) 2007, 2009 Rafael Fernández López <ereslibre@kde.org>
-  *
-  * This library is free software; you can redistribute it and/or
-  * modify it under the terms of the GNU Library General Public
-  * License as published by the Free Software Foundation; either
-  * version 2 of the License, or (at your option) any later version.
-  *
-  * This library is distributed in the hope that it will be useful,
-  * but WITHOUT ANY WARRANTY; without even the implied warranty of
-  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  * Library General Public License for more details.
-  *
-  * You should have received a copy of the GNU Library General Public License
-  * along with this library; see the file COPYING.LIB.  If not, write to
-  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  * Boston, MA 02110-1301, USA.
-  */
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007, 2009 Rafael Fernández López <ereslibre@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 /**
   * IMPLEMENTATION NOTES:
@@ -41,7 +28,7 @@
 
 //BEGIN: Private part
 
-struct KCategorizedView::Private::Item {
+struct KCategorizedViewPrivate::Item {
     Item()
         : topLeft(QPoint())
         , size(QSize())
@@ -52,16 +39,12 @@ struct KCategorizedView::Private::Item {
     QSize size;
 };
 
-struct KCategorizedView::Private::Block {
+struct KCategorizedViewPrivate::Block {
     Block()
         : topLeft(QPoint())
-        , height(-1)
         , firstIndex(QModelIndex())
         , quarantineStart(QModelIndex())
         , items(QList<Item>())
-        , outOfQuarantine(false)
-        , alternate(false)
-        , collapsed(false)
     {
     }
 
@@ -78,7 +61,7 @@ struct KCategorizedView::Private::Block {
     }
 
     QPoint topLeft;
-    int height;
+    int height = -1;
     QPersistentModelIndex firstIndex;
     // if we have n elements on this block, and we inserted an element at position i. The quarantine
     // will start at index (i, column, parent). This means that for all elements j where i <= j <= n, the
@@ -92,20 +75,15 @@ struct KCategorizedView::Private::Block {
     // this affects the whole block, not items separately. items contain the topLeft point relative
     // to the block. Because of insertions or removals a whole block can be moved, so the whole block
     // will enter in quarantine, what is faster than moving all items in absolute terms.
-    bool outOfQuarantine;
+    bool outOfQuarantine = false;
 
     // should we alternate its color ? is just a hint, could not be used
-    bool alternate;
-    bool collapsed;
+    bool alternate = false;
+    bool collapsed = false;
 };
 
-KCategorizedView::Private::Private(KCategorizedView *q)
+KCategorizedViewPrivate::KCategorizedViewPrivate(KCategorizedView *q)
     : q(q)
-    , proxyModel(nullptr)
-    , categoryDrawer(nullptr)
-    , categorySpacing(0)
-    , alternatingBlockColors(false)
-    , collapsibleBlocks(false)
     , hoveredBlock(new Block())
     , hoveredIndex(QModelIndex())
     , pressedPosition(QPoint())
@@ -113,17 +91,17 @@ KCategorizedView::Private::Private(KCategorizedView *q)
 {
 }
 
-KCategorizedView::Private::~Private()
+KCategorizedViewPrivate::~KCategorizedViewPrivate()
 {
     delete hoveredBlock;
 }
 
-bool KCategorizedView::Private::isCategorized() const
+bool KCategorizedViewPrivate::isCategorized() const
 {
     return proxyModel && categoryDrawer && proxyModel->isCategorizedModel();
 }
 
-QStyleOptionViewItem KCategorizedView::Private::blockRect(const QModelIndex &representative)
+QStyleOptionViewItem KCategorizedViewPrivate::blockRect(const QModelIndex &representative)
 {
     QStyleOptionViewItem option(q->viewOptions());
     const int height = categoryDrawer->categoryHeight(representative, option);
@@ -138,7 +116,7 @@ QStyleOptionViewItem KCategorizedView::Private::blockRect(const QModelIndex &rep
     return option;
 }
 
-QPair<QModelIndex, QModelIndex> KCategorizedView::Private::intersectingIndexesWithRect(const QRect &_rect) const
+QPair<QModelIndex, QModelIndex> KCategorizedViewPrivate::intersectingIndexesWithRect(const QRect &_rect) const
 {
     const int rowCount = proxyModel->rowCount();
 
@@ -179,7 +157,7 @@ QPair<QModelIndex, QModelIndex> KCategorizedView::Private::intersectingIndexesWi
     return qMakePair(bottomIndex, topIndex);
 }
 
-QPoint KCategorizedView::Private::blockPosition(const QString &category)
+QPoint KCategorizedViewPrivate::blockPosition(const QString &category)
 {
     Block &block = blocks[category];
 
@@ -191,7 +169,7 @@ QPoint KCategorizedView::Private::blockPosition(const QString &category)
 
     const QModelIndex index = block.firstIndex;
 
-    for (QHash<QString, Private::Block>::Iterator it = blocks.begin(); it != blocks.end(); ++it) {
+    for (auto it = blocks.begin(); it != blocks.end(); ++it) {
         Block &block = *it;
         const QModelIndex categoryIndex = block.firstIndex;
         if (index.row() < categoryIndex.row()) {
@@ -210,7 +188,7 @@ QPoint KCategorizedView::Private::blockPosition(const QString &category)
     return res;
 }
 
-int KCategorizedView::Private::blockHeight(const QString &category)
+int KCategorizedViewPrivate::blockHeight(const QString &category)
 {
     Block &block = blocks[category];
 
@@ -241,12 +219,12 @@ int KCategorizedView::Private::blockHeight(const QString &category)
     return height;
 }
 
-int KCategorizedView::Private::viewportWidth() const
+int KCategorizedViewPrivate::viewportWidth() const
 {
     return q->viewport()->width() - categorySpacing * 2 - categoryDrawer->leftMargin() - categoryDrawer->rightMargin();
 }
 
-void KCategorizedView::Private::regenerateAllElements()
+void KCategorizedViewPrivate::regenerateAllElements()
 {
     for (QHash<QString, Block>::Iterator it = blocks.begin(); it != blocks.end(); ++it) {
         Block &block = *it;
@@ -256,7 +234,7 @@ void KCategorizedView::Private::regenerateAllElements()
     }
 }
 
-void KCategorizedView::Private::rowsInserted(const QModelIndex &parent, int start, int end)
+void KCategorizedViewPrivate::rowsInserted(const QModelIndex &parent, int start, int end)
 {
     if (!isCategorized()) {
         return;
@@ -285,7 +263,7 @@ void KCategorizedView::Private::rowsInserted(const QModelIndex &parent, int star
 
         const int firstIndexRow = block.firstIndex.row();
 
-        block.items.insert(index.row() - firstIndexRow, Private::Item());
+        block.items.insert(index.row() - firstIndexRow, KCategorizedViewPrivate::Item());
         block.height = -1;
 
         q->visualRect(index);
@@ -296,7 +274,7 @@ void KCategorizedView::Private::rowsInserted(const QModelIndex &parent, int star
     {
         const QModelIndex lastIndex = proxyModel->index(end, q->modelColumn(), parent);
         const QString category = categoryForIndex(lastIndex);
-        Private::Block &block = blocks[category];
+        KCategorizedViewPrivate::Block &block = blocks[category];
         block.quarantineStart = block.firstIndex;
     }
     //END: update the items that are in quarantine in affected categories
@@ -314,8 +292,8 @@ void KCategorizedView::Private::rowsInserted(const QModelIndex &parent, int star
             firstIndexesRows << block.firstIndex.row();
         }
         //END: order for marking as alternate those blocks that are alternate
-        for (QHash<QString, Private::Block>::Iterator it = blocks.begin(); it != blocks.end(); ++it) {
-            Private::Block &block = *it;
+        for (auto it = blocks.begin(); it != blocks.end(); ++it) {
+            KCategorizedViewPrivate::Block &block = *it;
             if (block.firstIndex.row() > firstAffectedCategory.row()) {
                 block.outOfQuarantine = false;
                 block.alternate = firstIndexesRows.indexOf(block.firstIndex.row()) % 2;
@@ -327,21 +305,21 @@ void KCategorizedView::Private::rowsInserted(const QModelIndex &parent, int star
     //END: mark as in quarantine those categories that are under the affected ones
 }
 
-QRect KCategorizedView::Private::mapToViewport(const QRect &rect) const
+QRect KCategorizedViewPrivate::mapToViewport(const QRect &rect) const
 {
     const int dx = -q->horizontalOffset();
     const int dy = -q->verticalOffset();
     return rect.adjusted(dx, dy, dx, dy);
 }
 
-QRect KCategorizedView::Private::mapFromViewport(const QRect &rect) const
+QRect KCategorizedViewPrivate::mapFromViewport(const QRect &rect) const
 {
     const int dx = q->horizontalOffset();
     const int dy = q->verticalOffset();
     return rect.adjusted(dx, dy, dx, dy);
 }
 
-int KCategorizedView::Private::highestElementInLastRow(const Block &block) const
+int KCategorizedViewPrivate::highestElementInLastRow(const Block &block) const
 {
     //Find the highest element in the last row
     const QModelIndex lastIndex = proxyModel->index(block.firstIndex.row() + block.items.count() - 1, q->modelColumn(), q->rootIndex());
@@ -368,19 +346,19 @@ int KCategorizedView::Private::highestElementInLastRow(const Block &block) const
     return res;
 }
 
-bool KCategorizedView::Private::hasGrid() const
+bool KCategorizedViewPrivate::hasGrid() const
 {
     const QSize gridSize = q->gridSize();
     return gridSize.isValid() && !gridSize.isNull();
 }
 
-QString KCategorizedView::Private::categoryForIndex(const QModelIndex &index) const
+QString KCategorizedViewPrivate::categoryForIndex(const QModelIndex &index) const
 {
     const QModelIndex categoryIndex = index.model()->index(index.row(), proxyModel->sortColumn(), index.parent());
     return categoryIndex.data(KCategorizedSortFilterProxyModel::CategoryDisplayRole).toString();
 }
 
-void KCategorizedView::Private::leftToRightVisualRect(const QModelIndex &index, Item &item,
+void KCategorizedViewPrivate::leftToRightVisualRect(const QModelIndex &index, Item &item,
         const Block &block, const QPoint &blockPos) const
 {
     const int firstIndexRow = block.firstIndex.row();
@@ -458,7 +436,7 @@ void KCategorizedView::Private::leftToRightVisualRect(const QModelIndex &index,
     item.size = q->sizeHintForIndex(index);
 }
 
-void KCategorizedView::Private::topToBottomVisualRect(const QModelIndex &index, Item &item,
+void KCategorizedViewPrivate::topToBottomVisualRect(const QModelIndex &index, Item &item,
         const Block &block, const QPoint &blockPos) const
 {
     const int firstIndexRow = block.firstIndex.row();
@@ -490,7 +468,7 @@ void KCategorizedView::Private::topToBottomVisualRect(const QModelIndex &index,
     item.size.setWidth(viewportWidth());
 }
 
-void KCategorizedView::Private::_k_slotCollapseOrExpandClicked(QModelIndex)
+void KCategorizedViewPrivate::_k_slotCollapseOrExpandClicked(QModelIndex)
 {
 }
 
@@ -500,14 +478,11 @@ void KCategorizedView::Private::_k_slotCollapseOrExpandClicked(QModelIndex)
 
 KCategorizedView::KCategorizedView(QWidget *parent)
     : QListView(parent)
-    , d(new Private(this))
+    , d(new KCategorizedViewPrivate(this))
 {
 }
 
-KCategorizedView::~KCategorizedView()
-{
-    delete d;
-}
+KCategorizedView::~KCategorizedView() = default;
 
 void KCategorizedView::setModel(QAbstractItemModel *model)
 {
@@ -562,7 +537,7 @@ QRect KCategorizedView::visualRect(const QModelIndex &index) const
         return QRect();
     }
 
-    Private::Block &block = d->blocks[category];
+    KCategorizedViewPrivate::Block &block = d->blocks[category];
     const int firstIndexRow = block.firstIndex.row();
 
     Q_ASSERT(block.firstIndex.isValid());
@@ -573,7 +548,7 @@ QRect KCategorizedView::visualRect(const QModelIndex &index) const
 
     const QPoint blockPos = d->blockPosition(category);
 
-    Private::Item &ritem = block.items[index.row() - firstIndexRow];
+    KCategorizedViewPrivate::Item &ritem = block.items[index.row() - firstIndexRow];
 
     if (ritem.topLeft.isNull() || (block.quarantineStart.isValid() &&
                                    index.row() >= block.quarantineStart.row())) {
@@ -598,7 +573,7 @@ QRect KCategorizedView::visualRect(const QModelIndex &index) const
 
     // we get now the absolute position through the relative position of the parent block. do not
     // save this on ritem, since this would override the item relative position in block terms.
-    Private::Item item(ritem);
+    KCategorizedViewPrivate::Item item(ritem);
     item.topLeft.ry() += blockPos.y();
 
     const QSize sizeHint = item.size;
@@ -658,8 +633,8 @@ void KCategorizedView::setCategorySpacing(int categorySpacing)
 
     d->categorySpacing = categorySpacing;
 
-    for (QHash<QString, Private::Block>::Iterator it = d->blocks.begin(); it != d->blocks.end(); ++it) {
-        Private::Block &block = *it;
+    for (auto it = d->blocks.begin(); it != d->blocks.end(); ++it) {
+        KCategorizedViewPrivate::Block &block = *it;
         block.outOfQuarantine = false;
     }
 }
@@ -687,7 +662,7 @@ void KCategorizedView::setCollapsibleBlocks(bool enable)
 QModelIndexList KCategorizedView::block(const QString &category)
 {
     QModelIndexList res;
-    const Private::Block &block = d->blocks[category];
+    const KCategorizedViewPrivate::Block &block = d->blocks[category];
     if (block.height == -1) {
         return res;
     }
@@ -794,9 +769,9 @@ void KCategorizedView::paintEvent(QPaintEvent *event)
     Q_ASSERT(selectionModel()->model() == d->proxyModel);
 
     //BEGIN: draw categories
-    QHash<QString, Private::Block>::ConstIterator it(d->blocks.constBegin());
+    auto it = d->blocks.constBegin();
     while (it != d->blocks.constEnd()) {
-        const Private::Block &block = *it;
+        const KCategorizedViewPrivate::Block &block = *it;
         const QModelIndex categoryIndex = d->proxyModel->index(block.firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
         QStyleOptionViewItem option(viewOptions());
         option.features |= d->alternatingBlockColors && block.alternate ? QStyleOptionViewItem::Alternate
@@ -825,7 +800,7 @@ void KCategorizedView::paintEvent(QPaintEvent *event)
         int indexToCheckIfBlockCollapsed = i;
         QModelIndex categoryIndex;
         QString category;
-        Private::Block *block = nullptr;
+        KCategorizedViewPrivate::Block *block = nullptr;
         while (i <= intersecting.second.row()) {
             //BEGIN: first check if the block is collapsed. if so, we have to skip the item painting
             if (i == indexToCheckIfBlockCollapsed) {
@@ -955,9 +930,9 @@ void KCategorizedView::mouseMoveEvent(QMouseEvent *event)
     if (!d->categoryDrawer) {
         return;
     }
-    QHash<QString, Private::Block>::ConstIterator it(d->blocks.constBegin());
+    auto it = d->blocks.constBegin();
     while (it != d->blocks.constEnd()) {
-        const Private::Block &block = *it;
+        const KCategorizedViewPrivate::Block &block = *it;
         const QModelIndex categoryIndex = d->proxyModel->index(block.firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
         QStyleOptionViewItem option(viewOptions());
         const int height = d->categoryDrawer->categoryHeight(categoryIndex, option);
@@ -991,7 +966,7 @@ void KCategorizedView::mouseMoveEvent(QMouseEvent *event)
         const QModelIndex categoryIndex = d->proxyModel->index(d->hoveredBlock->firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
         const QStyleOptionViewItem option = d->blockRect(categoryIndex);
         d->categoryDrawer->mouseLeft(categoryIndex, option.rect);
-        *d->hoveredBlock = Private::Block();
+        *d->hoveredBlock = KCategorizedViewPrivate::Block();
         d->hoveredCategory = QString();
         viewport()->update(option.rect);
     }
@@ -1008,9 +983,9 @@ void KCategorizedView::mousePressEvent(QMouseEvent *event)
         QListView::mousePressEvent(event);
         return;
     }
-    QHash<QString, Private::Block>::ConstIterator it(d->blocks.constBegin());
+    auto it = d->blocks.constBegin();
     while (it != d->blocks.constEnd()) {
-        const Private::Block &block = *it;
+        const KCategorizedViewPrivate::Block &block = *it;
         const QModelIndex categoryIndex = d->proxyModel->index(block.firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
         const QStyleOptionViewItem option = d->blockRect(categoryIndex);
         const QPoint mousePos = viewport()->mapFromGlobal(QCursor::pos());
@@ -1035,9 +1010,9 @@ void KCategorizedView::mouseReleaseEvent(QMouseEvent *event)
         QListView::mouseReleaseEvent(event);
         return;
     }
-    QHash<QString, Private::Block>::ConstIterator it(d->blocks.constBegin());
+    auto it = d->blocks.constBegin();
     while (it != d->blocks.constEnd()) {
-        const Private::Block &block = *it;
+        const KCategorizedViewPrivate::Block &block = *it;
         const QModelIndex categoryIndex = d->proxyModel->index(block.firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
         const QStyleOptionViewItem option = d->blockRect(categoryIndex);
         const QPoint mousePos = viewport()->mapFromGlobal(QCursor::pos());
@@ -1065,7 +1040,7 @@ void KCategorizedView::leaveEvent(QEvent *event)
         const QModelIndex categoryIndex = d->proxyModel->index(d->hoveredBlock->firstIndex.row(), d->proxyModel->sortColumn(), rootIndex());
         const QStyleOptionViewItem option = d->blockRect(categoryIndex);
         d->categoryDrawer->mouseLeft(categoryIndex, option.rect);
-        *d->hoveredBlock = Private::Block();
+        *d->hoveredBlock = KCategorizedViewPrivate::Block();
         d->hoveredCategory = QString();
         viewport()->update(option.rect);
     }
@@ -1146,7 +1121,7 @@ QModelIndex KCategorizedView::moveCursor(CursorAction cursorAction,
             const QModelIndex current = currentIndex();
             const QSize itemSize = d->hasGrid() ? gridSize()
                                    : sizeHintForIndex(current);
-            const Private::Block &block = d->blocks[d->categoryForIndex(current)];
+            const KCategorizedViewPrivate::Block &block = d->blocks[d->categoryForIndex(current)];
             const int maxItemsPerRow = qMax(d->viewportWidth() / itemSize.width(), 1);
             const bool canMove = current.row() + maxItemsPerRow < block.firstIndex.row() +
                                  block.items.count();
@@ -1162,7 +1137,7 @@ QModelIndex KCategorizedView::moveCursor(CursorAction cursorAction,
                 return QModelIndex();
             }
 
-            const Private::Block &nextBlock = d->blocks[d->categoryForIndex(nextIndex)];
+            const KCategorizedViewPrivate::Block &nextBlock = d->blocks[d->categoryForIndex(nextIndex)];
 
             if (nextBlock.items.count() <= currentRelativePos) {
                 return QModelIndex();
@@ -1180,7 +1155,7 @@ QModelIndex KCategorizedView::moveCursor(CursorAction cursorAction,
             const QModelIndex current = currentIndex();
             const QSize itemSize = d->hasGrid() ? gridSize()
                                    : sizeHintForIndex(current);
-            const Private::Block &block = d->blocks[d->categoryForIndex(current)];
+            const KCategorizedViewPrivate::Block &block = d->blocks[d->categoryForIndex(current)];
             const int maxItemsPerRow = qMax(d->viewportWidth() / itemSize.width(), 1);
             const bool canMove = current.row() - maxItemsPerRow >= block.firstIndex.row();
 
@@ -1195,7 +1170,7 @@ QModelIndex KCategorizedView::moveCursor(CursorAction cursorAction,
                 return QModelIndex();
             }
 
-            const Private::Block &prevBlock = d->blocks[d->categoryForIndex(prevIndex)];
+            const KCategorizedViewPrivate::Block &prevBlock = d->blocks[d->categoryForIndex(prevIndex)];
 
             if (prevBlock.items.count() <= currentRelativePos) {
                 return QModelIndex();
@@ -1226,7 +1201,7 @@ void KCategorizedView::rowsAboutToBeRemoved(const QModelIndex &parent,
         return;
     }
 
-    *d->hoveredBlock = Private::Block();
+    *d->hoveredBlock = KCategorizedViewPrivate::Block();
     d->hoveredCategory = QString();
 
     if (end - start + 1 == d->proxyModel->rowCount()) {
@@ -1285,7 +1260,7 @@ void KCategorizedView::rowsAboutToBeRemoved(const QModelIndex &parent,
             alreadyRemoved = 0;
         }
 
-        Private::Block &block = d->blocks[category];
+        KCategorizedViewPrivate::Block &block = d->blocks[category];
         block.items.removeAt(i - block.firstIndex.row() - alreadyRemoved);
         ++alreadyRemoved;
 
@@ -1302,7 +1277,7 @@ void KCategorizedView::rowsAboutToBeRemoved(const QModelIndex &parent,
     {
         const QModelIndex lastIndex = d->proxyModel->index(end, modelColumn(), parent);
         const QString category = d->categoryForIndex(lastIndex);
-        Private::Block &block = d->blocks[category];
+        KCategorizedViewPrivate::Block &block = d->blocks[category];
         if (!block.items.isEmpty() && start <= block.firstIndex.row() && end >= block.firstIndex.row()) {
             block.firstIndex = d->proxyModel->index(end + 1, modelColumn(), parent);
         }
@@ -1317,15 +1292,15 @@ void KCategorizedView::rowsAboutToBeRemoved(const QModelIndex &parent,
     //BEGIN: mark as in quarantine those categories that are under the affected ones
     {
         //BEGIN: order for marking as alternate those blocks that are alternate
-        QList<Private::Block> blockList = d->blocks.values();
-        std::sort(blockList.begin(), blockList.end(), Private::Block::lessThan);
+        QList<KCategorizedViewPrivate::Block> blockList = d->blocks.values();
+        std::sort(blockList.begin(), blockList.end(), KCategorizedViewPrivate::Block::lessThan);
         QList<int> firstIndexesRows;
-        for (const Private::Block &block : qAsConst(blockList)) {
+        for (const KCategorizedViewPrivate::Block &block : qAsConst(blockList)) {
             firstIndexesRows << block.firstIndex.row();
         }
         //END: order for marking as alternate those blocks that are alternate
-        for (QHash<QString, Private::Block>::Iterator it = d->blocks.begin(); it != d->blocks.end(); ++it) {
-            Private::Block &block = *it;
+        for (auto it = d->blocks.begin(); it != d->blocks.end(); ++it) {
+            KCategorizedViewPrivate::Block &block = *it;
             if (block.firstIndex.row() > start) {
                 block.outOfQuarantine = false;
                 block.alternate = firstIndexesRows.indexOf(block.firstIndex.row()) % 2;
@@ -1452,7 +1427,7 @@ void KCategorizedView::dataChanged(const QModelIndex &topLeft,
         return;
     }
 
-    *d->hoveredBlock = Private::Block();
+    *d->hoveredBlock = KCategorizedViewPrivate::Block();
     d->hoveredCategory = QString();
 
     //BEGIN: since the model changed data, we need to reconsider item sizes
@@ -1460,7 +1435,7 @@ void KCategorizedView::dataChanged(const QModelIndex &topLeft,
     int indexToCheck = i;
     QModelIndex categoryIndex;
     QString category;
-    Private::Block *block;
+    KCategorizedViewPrivate::Block *block;
     while (i <= bottomRight.row()) {
         const QModelIndex currIndex = d->proxyModel->index(i, modelColumn(), rootIndex());
         if (i == indexToCheck) {
@@ -1485,7 +1460,7 @@ void KCategorizedView::rowsInserted(const QModelIndex &parent,
         return;
     }
 
-    *d->hoveredBlock = Private::Block();
+    *d->hoveredBlock = KCategorizedViewPrivate::Block();
     d->hoveredCategory = QString();
     d->rowsInserted(parent, start, end);
 }
@@ -1519,7 +1494,7 @@ void KCategorizedView::slotLayoutChanged()
     }
 
     d->blocks.clear();
-    *d->hoveredBlock = Private::Block();
+    *d->hoveredBlock = KCategorizedViewPrivate::Block();
     d->hoveredCategory = QString();
     if (d->proxyModel->rowCount()) {
         d->rowsInserted(rootIndex(), 0, d->proxyModel->rowCount() - 1);
